@@ -43,3 +43,9 @@ word_tbl_filter <- function(x, words, keep) {
     map(x, tokenlist_filter, words, keep)
   )
 }
+
+table0 <- function(x) {
+  res <- dplyr::count(tibble(tokens = x), tokens)
+  
+  purrr::set_names(res$n, res$tokens)
+}
\ No newline at end of file
