@@ -3,19 +3,11 @@
 #' `step_sequence_onehot` creates a *specification* of a recipe step that
 #'  will take a string and do one hot encoding for each character by position.
 #'
-#' @param recipe A recipe object. The step will be added to the
-#'  sequence of operations for this recipe.
-#' @param ... One or more selector functions to choose variables.
-#'  For `step_sequence_onehot`, this indicates the variables to be encoded
-#'  into a [tokenlist]. See [recipes::selections()] for more
-#'  details. For the `tidy` method, these are not currently used.
-#' @param role For model terms created by this step, what analysis
-#'  role should they be assigned?. By default, the function assumes
-#'  that the new columns created by the original variables will be
-#'  used as predictors in a model.
-#' @param columns A list of tibble results that define the
-#'  encoding. This is `NULL` until the step is trained by
-#'  [recipes::prep.recipe()].
+#' @template args-recipe
+#' @template args-dots
+#' @template args-role_predictors
+#' @template args-trained
+#' @template args-columns
 #' @param sequence_length A numeric, number of characters to keep before
 #'      discarding. Defaults to 100.
 #' @param padding 'pre' or 'post', pad either before or after each sequence.
@@ -27,18 +19,21 @@
 #'  Characters not in the vocabulary will be encoded as 0. Defaults to
 #'  `letters`.
 #' @param prefix A prefix for generated column names, default to "seq1hot".
-#' @param skip A logical. Should the step be skipped when the
-#'  recipe is baked by [recipes::bake.recipe()]? While all
-#'  operations are baked when [recipes::prep.recipe()] is run, some
-#'  operations may not be able to be conducted on new data (e.g.
-#'  processing the outcome variable(s)). Care should be taken when
-#'  using `skip = TRUE` as it may affect the computations for
-#'  subsequent operations.
-#' @param id A character string that is unique to this step to identify it
-#' @param trained A logical to indicate if the recipe has been
-#'  baked.
-#' @return An updated version of `recipe` with the new step added
-#'  to the sequence of existing steps (if any).
+#' @template args-skip
+#' @template args-id
+#' 
+#' @source \url{https://papers.nips.cc/paper/5782-character-level-convolutional-networks-for-text-classification.pdf}
+#' 
+#' @template returns
+#' 
+#' @details
+#' The string will be capped by the sequence_length argument, strings shorter then
+#' sequence_length will be padded with empty characters. The encoding will assign
+#' a integer to each character in the vocabulary, and will encode accordingly.
+#' Characters not in the vocabulary will be encoded as 0.
+#' 
+#' @family character to numeric steps
+#' 
 #' @examples
 #' library(recipes)
 #' library(modeldata)
@@ -56,16 +51,8 @@
 #'
 #' tidy(okc_rec, number = 1)
 #' tidy(okc_obj, number = 1)
+#' 
 #' @export
-#' @details
-#' The string will be capped by the sequence_length argument, strings shorter then
-#' sequence_length will be padded with empty characters. The encoding will assign
-#' a integer to each character in the vocabulary, and will encode accordingly.
-#' Characters not in the vocabulary will be encoded as 0.
-#'
-#' @source \url{https://papers.nips.cc/paper/5782-character-level-convolutional-networks-for-text-classification.pdf}
-#'
-#' @family character to numeric steps
 step_sequence_onehot <-
   function(recipe,
            ...,
@@ -250,7 +237,10 @@ string2encoded_matrix <- function(x, vocabulary, sequence_length, padding,
       }
     }
   }
-  res <- matrix(vocabulary[res], nrow = length(x), ncol = sequence_length)
+  res <- matrix(
+    vocabulary[match(res, names(vocabulary))], 
+    nrow = length(x), ncol = sequence_length
+  )
   res[is.na(res)] <- 0
   res
 }
