@@ -3,17 +3,11 @@
 #' `step_tokenfilter` creates a *specification* of a recipe step that
 #'  will convert a [tokenlist] to be filtered based on frequency.
 #'
-#' @param recipe A recipe object. The step will be added to the
-#'  sequence of operations for this recipe.
-#' @param ... One or more selector functions to choose variables.
-#'  For `step_tokenfilter`, this indicates the variables to be encoded
-#'  into a [tokenlist]. See [recipes::selections()] for more
-#'  details. For the `tidy` method, these are not currently used.
-#' @param role Not used by this step since no new variables are
-#'  created.
-#' @param columns A list of tibble results that define the
-#'  encoding. This is `NULL` until the step is trained by
-#'  [recipes::prep.recipe()].
+#' @template args-recipe
+#' @template args-dots
+#' @template args-role_no-new
+#' @template args-trained
+#' @template args-columns
 #' @param max_times An integer. Maximal number of times a word can appear
 #'  before getting removed.
 #' @param min_times An integer. Minimum number of times a word can appear
@@ -24,18 +18,28 @@
 #'  after filtering done by max_times and min_times. Defaults to 100.
 #' @param res The words that will be keep will be stored here once
 #'  this preprocessing step has be trained by [prep.recipe()].
-#' @param skip A logical. Should the step be skipped when the
-#'  recipe is baked by [recipes::bake.recipe()]? While all
-#'  operations are baked when [recipes::prep.recipe()] is run, some
-#'  operations may not be able to be conducted on new data (e.g.
-#'  processing the outcome variable(s)). Care should be taken when
-#'  using `skip = TRUE` as it may affect the computations for
-#'  subsequent operations.
-#' @param id A character string that is unique to this step to identify it.
-#' @param trained A logical to indicate if the recipe has been
-#'  baked.
-#' @return An updated version of `recipe` with the new step added
-#'  to the sequence of existing steps (if any).
+#' @template args-skip
+#' @template args-id
+#' 
+#' @template returns
+#' 
+#' @details
+#' This step allow you to limit the tokens you are looking at by filtering
+#' on their occurrence in the corpus. You are able to exclude tokens if they
+#' appear too many times or too fews times in the data. It can be specified
+#' as counts using `max_times` and `min_times` or as percentages by setting
+#' `percentage` as `TRUE`. In addition one can filter to only use the top
+#' `max_tokens` used tokens. If `max_tokens` is set to `Inf` then all the tokens
+#' will be used. This will generally lead to very large datasets when then
+#' tokens are words or trigrams. A good strategy is to start with a low token
+#' count and go up according to how much RAM you want to use.
+#'
+#' It is strongly advised to filter before using [step_tf] or [step_tfidf] to
+#' limit the number of variables created.
+#'
+#' @seealso [step_tokenize()] to turn character into tokenlist.
+#' @family tokenlist to tokenlist steps
+#' 
 #' @examples
 #' library(recipes)
 #' library(modeldata)
@@ -57,23 +61,8 @@
 #'
 #' tidy(okc_rec, number = 2)
 #' tidy(okc_obj, number = 2)
+#' 
 #' @export
-#' @details
-#' This step allow you to limit the tokens you are looking at by filtering
-#' on their occurrence in the corpus. You are able to exclude tokens if they
-#' appear too many times or too fews times in the data. It can be specified
-#' as counts using `max_times` and `min_times` or as percentages by setting
-#' `percentage` as `TRUE`. In addition one can filter to only use the top
-#' `max_tokens` used tokens. If `max_tokens` is set to `Inf` then all the tokens
-#' will be used. This will generally lead to very large datasets when then
-#' tokens are words or trigrams. A good strategy is to start with a low token
-#' count and go up according to how much RAM you want to use.
-#'
-#' It is strongly advised to filter before using [step_tf] or [step_tfidf] to
-#' limit the number of variables created.
-#'
-#' @seealso [step_tokenize()] to turn character into tokenlist.
-#' @family tokenlist to tokenlist steps
 step_tokenfilter <-
   function(recipe,
            ...,
@@ -147,7 +136,7 @@ prep.step_tokenfilter <- function(x, training, info = NULL, ...) {
       x$percentage
     )
 
-    n_words[[i]] <- length(table(unlist(training[, col_names[i], drop = TRUE])))
+    n_words[[i]] <- length(unique(unlist(training[, col_names[i], drop = TRUE])))
   }
 
   step_tokenfilter_new(
@@ -215,7 +204,7 @@ tidy.step_tokenfilter <- function(x, ...) {
 ## Implementation
 tokenfilter_fun <- function(data, max_times, min_times, max_features,
                             percentage) {
-  tf <- table(unlist(get_tokens(data)))
+  tf <- table0(unlist(get_tokens(data)))
 
   if (percentage) {
     tf <- tf / sum(tf)
